interrupt

Function interrupt 

pub fn interrupt(
    node: impl Into<String>,
    value: Option<Value>,
) -> AgentGraphError
Create an interrupt error that can be returned from within a node. This causes the graph executor to pause execution at the current node.