pub struct PayloadNode { /* private fields */ }Expand description
A node that wraps a Payload for execution within the graph.
input_selector extracts what to pass to the payload from graph state.
output_mapper folds the payload output back into graph state.
Defaults: pass entire state as input; replace entire state with output.value.
Implementations
Sourceimpl PayloadNode
impl PayloadNode
Sourcepub fn with_name(self, name: impl Into<String>) -> Self
pub fn with_name(self, name: impl Into<String>) -> Self
Set a name for this node (for debugging and events).
Sourcepub fn with_input_selector(
self,
selector: impl Fn(&Value) -> Value + Send + Sync + 'static,
) -> Self
pub fn with_input_selector( self, selector: impl Fn(&Value) -> Value + Send + Sync + 'static, ) -> Self
Set the input selector function.
Receives the entire state as a JSON value and returns the value
to pass to the payload’s invoke method.
Sourcepub fn with_output_mapper(
self,
mapper: impl Fn(&Value, &PayloadOutput) -> Value + Send + Sync + 'static,
) -> Self
pub fn with_output_mapper( self, mapper: impl Fn(&Value, &PayloadOutput) -> Value + Send + Sync + 'static, ) -> Self
Set the output mapper function.
Receives the current state and the payload output, returns the new state.