Structs
- AddReducer
- Add reducer: adds numeric values together.
- Append
Reducer - Append reducer: appends items from the update array to the current array.
- FnReducer
- Closure-based reducer for custom logic.
- Last
Write Wins - Default reducer: the new value replaces the old value.
- Merge
Reducer - Merge reducer: deep-merges JSON objects.
Traits
- Reducer
- A reducer combines old and new values during state updates. Critical for correctness during parallel execution.